ListTab class

Constructors

ListTab({Widget? icon, required Widget label, BorderRadiusGeometry borderRadius = const BorderRadius.all(const Radius.circular(5.0)), Color activeBackgroundColor = Colors.blue, Color inactiveBackgroundColor = Colors.transparent, bool showIconOnList = false, Color borderColor = Colors.grey})
Create a new ListTab
const

Properties

activeBackgroundColor → Color
Color to be used when the tab is selected.
final
borderColor → Color
Color of the Border property of the inner tab Container.
final
borderRadius → BorderRadiusGeometry
BorderRadius for the a tab at the bottom tab view. This won't affect the tab in the scrollable list.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
Trailing widget for a tab, typically an Icon.
final
inactiveBackgroundColor → Color
Color to be used when tab is not selected
final
label → Widget
Label to be shown in the tab, must be non-null.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showIconOnList → bool
If true, the icon will also be shown to the user in the scrollable list.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited